import { IconDefinition } from '@fortawesome/fontawesome-svg-core';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';

import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  className: 'btn',
  disabled: false,
  margin: '0em',
  backgroundColor: colors.theme.light_blue,
  text: 'LISTA DE ALUNOS',
  icon: fontawesome.icons.faComments,
  color: colors.theme.white,
  sizeIcon: '1.125em',
  textSize: '1em',
  width: '16.25em',
  height: '5em',
  disableIcon: false,
  iconWidth: 'undefined',
  fontWeight: '900',
  display: 'flex',
  boxShadow: '0 0 0 0',
  onClick: () => {
    console.log('clicou');
  },
  onChange: () => {
    console.log('mudou');
  },
};

type ButtonProps = {
  className?: string;
  margin?: string;
  disabled?: boolean;
  backgroundColor?: string;
  text?: string;
  color?: string;
  icon?: IconDefinition;
  sizeIcon?: string;
  textSize?: string;
  width?: string;
  height?: string;
  fontWeight?: string;
  boxShadow?: string;
  onClick?: () => void;
  disableIcon?: boolean;
  iconWidth?: string;
  display?: string;
  onChange?: () => void;
} & typeof defaultProps;

function ButtonCard(props: ButtonProps) {
  const {
    display,
    className,
    text,
    disabled,
    backgroundColor,
    color,
    icon,
    sizeIcon,
    textSize,
    height,
    width,
    onClick,
    iconWidth,
    disableIcon,
    margin,
    fontWeight,
    boxShadow,
    onChange,
  } = props;

  const styles = {
    button: {
      margin,
      backgroundColor,
      color,
      fontSize: textSize,
      fontStyle: 'roboto',
      fontWeight: '900',
      height,
      width,
      boxShadow,
      justifyContent: 'center',
      alignItems: 'center',
      display,
    },
    icon: {
      marginRight: '1rem',
      fontSize: `${sizeIcon}`,
      width: iconWidth !== 'undefined' ? `${iconWidth}` : undefined,
    },
    text: {
      marginBottom: '0px',
    },
  };

  return (
    <button
      className={className}
      style={styles.button}
      type="submit"
      disabled={disabled}
      onClick={onClick}
    >
      {!disableIcon && <FontAwesomeIcon icon={icon} style={styles.icon} />}
      <span style={styles.text}>{text}</span>
    </button>
  );
}

ButtonCard.defaultProps = defaultProps;

export default ButtonCard;
