/* eslint-disable no-nested-ternary */
import { IconDefinition } from '@fortawesome/fontawesome-svg-core';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';

import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  className: 'textField',
  placeholder: 'Digite alguma coisa aqui',
  value: '',
  acceptValue: false,
  textColor: colors.theme.text_icon,
  borderColor: colors.theme.text_icon,
  backgroundColor: colors.theme.white,
  fontSize: '1rem',
  icon: fontawesome.icons.faMagnifyingGlass,
  iconSize: '1.875rem',
  iconColor: colors.theme.text_icon,
  disableIcon: true,
  disableIconClick: true,
  rightIconLocation: true,
  inputTypeText: true,
  width: '85%',
  maxWidth: '66.8rem',
  height: '3.25rem',
  margin: '1.5625rem 0rem 0rem 0rem',
  borderRadius: '0.3125rem',
  onChange: (event: React.ChangeEvent<HTMLInputElement>) => {
    console.log(event);
  },
  onClickIcon: () => {
    console.log('clicked on the icon!');
  },
};

type TextFieldProps = {
  className?: string;
  placeholder?: string;
  value?: string;
  acceptValue?: boolean;
  textColor?: string;
  borderColor?: string;
  backgroundColor?: string;
  fontSize?: string;
  icon?: IconDefinition;
  iconSize?: string;
  iconColor?: string;
  disableIcon?: boolean;
  disableIconClick?: boolean;
  rightIconLocation?: boolean;
  inputTypeText?: boolean;
  width?: string;
  maxWidth?: string;
  height?: string;
  margin?: string;
  borderRadius?: string;
  onChange?: (event: React.ChangeEvent<HTMLInputElement>) => void;
  onClickIcon?: () => void;
} & typeof defaultProps;

function TextField(props: TextFieldProps) {
  const {
    className,
    placeholder,
    value,
    acceptValue,
    textColor,
    borderColor,
    backgroundColor,
    fontSize,
    icon,
    iconSize,
    iconColor,
    disableIcon,
    disableIconClick,
    rightIconLocation,
    inputTypeText,
    width,
    maxWidth,
    height,
    margin,
    borderRadius,
    onChange,
    onClickIcon,
  } = props;

  const styles = {
    input: {
      fontSize,
      fontStyle: 'roboto',
      color: `${textColor}`,
      padding: '1.0625rem 0.875rem 1.0625rem 1.0625rem',
      fontWeight: '400',
      spellCheck: 'false',
      outline: 'none',
      border: 'none',
      borderRadius,
      flexGrow: '1',
    },
    rightIcon: {
      color: `${iconColor}`,
      fontSize: `${iconSize}`,
      margin: '0.688rem 1.25rem 0.688rem 0rem',
    },
    rightIconClick: {
      color: `${iconColor}`,
      fontSize: `${iconSize}`,
      cursor: 'pointer',
      margin: '0.688rem 1.25rem 0.688rem 0rem',
    },
    leftIcon: {
      color: `${iconColor}`,
      fontSize: `${iconSize}`,
      margin: '0.688rem 0rem 0.688rem 1.063rem',
    },
    leftIconClick: {
      color: `${iconColor}`,
      fontSize: `${iconSize}`,
      cursor: 'pointer',
      margin: '0.688rem 0rem 0.688rem 1.063rem',
    },
    form: {
      display: 'inline-flex',
      border: `0.081rem solid ${borderColor}`,
      minWidth: '20.1875rem',
      maxWidth,
      width,
      height,
      borderRadius,
      margin,
      backgroundColor,
    },
  };

  return (
    <form style={styles.form}>
      {!rightIconLocation &&
        !disableIcon &&
        (!disableIconClick ? (
          <FontAwesomeIcon
            icon={icon}
            style={styles.leftIconClick}
            onClick={onClickIcon}
          />
        ) : (
          <FontAwesomeIcon icon={icon} style={styles.leftIcon} />
        ))}

      {inputTypeText ? (
        acceptValue ? (
          <input
            style={styles.input}
            className={className}
            onChange={onChange}
            type="text"
            placeholder={placeholder}
            value={value}
          />
        ) : (
          <input
            style={styles.input}
            className={className}
            onChange={onChange}
            type="text"
            placeholder={placeholder}
          />
        )
      ) : (
        <input
          style={styles.input}
          className={className}
          onChange={onChange}
          type="password"
          placeholder={placeholder}
        />
      )}

      {rightIconLocation &&
        !disableIcon &&
        (!disableIconClick ? (
          <FontAwesomeIcon
            icon={icon}
            style={styles.rightIconClick}
            onClick={onClickIcon}
          />
        ) : (
          <FontAwesomeIcon icon={icon} style={styles.rightIcon} />
        ))}
    </form>
  );
}
TextField.defaultProps = defaultProps;

export default TextField;
