import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { ButtonCard, TextField, TitleComponent } from '../components';
import TextArea from '../components/TextArea';
import { Header, Modal } from '../containers';
import { StudentData } from '../model/student';
import {
  createStudentData,
  CreateStudentDataPayload,
  deleteStudentData,
  editStudentData,
  getStudentDataById,
} from '../services/studentData';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const styles = {
  modal: {
    position: 'absolute' as const,
    alignself: 'center',
    justifyContent: 'center',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
  },
};

function AdicionarDado() {
  const { idAluno, id } = useParams();
  const navigate = useNavigate();
  const [isEdicao, setIsEdicao] = useState<boolean>(false);
  const [subject, setSubject] = useState<string>('');
  const [content, setContent] = useState<string>('');
  const [modalDelete, setModalDelete] = useState(false);
  const [modalSuccess, setModalSuccess] = useState(false);
  const [modalEmpty, setModalEmpty] = useState(false);
  const [modalDeleteConfirmed, setModalDeleteConfirmed] = useState(false);

  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };
  const toggleModalDelete = () => {
    setModalDelete(!modalDelete);
  };
  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };
  const toggleModalDeleteConfirmed = () => {
    setModalDeleteConfirmed(!modalDeleteConfirmed);
  };

  const handleClickSave = (data: CreateStudentDataPayload) => {
    if (isEdicao) editStudentData(Number(idAluno), data, Number(id));
    else createStudentData(Number(idAluno), data);
  };
  const handleClickDelete = () =>
    deleteStudentData(Number(idAluno), Number(id));

  useEffect(() => {
    const getData = async (studentId: number, id: number) => {
      try {
        const getStudentDataResponse: StudentData = await getStudentDataById(
          studentId,
          id,
        );
        setSubject(getStudentDataResponse.subject);
        setContent(getStudentDataResponse.content);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      setIsEdicao(true);
      getData(Number(idAluno), Number(id));
    }
  }, []);

  return (
    <div
      style={{
        backgroundColor: colors.theme.background,
        minHeight: '100vh',
        paddingBottom: '2rem',
        marginTop: '6.25rem',
      }}
    >
      <div className="fixed-top">
        <Header text="Área do Aluno" disableArrow enableLogout />
      </div>

      <div style={{ paddingTop: '1.563rem' }}>
        <TitleComponent
          text={isEdicao ? 'Editar Dado' : 'Adicionar Dado'}
          textSize="1.75em"
          fontWeight="600"
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Digite um aspecto do aluno"
          acceptValue
          value={subject}
          onChange={event => setSubject(event.target.value)}
        />
      </div>
      <div
        style={{
          marginTop: '1.563rem',
        }}
      >
        <TextArea
          placeholder="Digite o detalhamento de tal aspecto"
          height="25.5625rem"
          acceptValue
          value={content}
          setChange={event => setContent(event.target.value)}
        />
      </div>
      {isEdicao ? (
        <>
          <div
            style={{
              display: 'flex',
              justifyContent: 'center',
              marginTop: '2.75rem',
            }}
          >
            <ButtonCard
              text=""
              backgroundColor={colors.theme.blue}
              width="8.75rem"
              height="3.25rem"
              iconWidth="100%"
              sizeIcon="2.25em"
              icon={fontawesome.icons.faXmark}
              onClick={() => navigate(-1)}
            />

            <ButtonCard
              text=""
              backgroundColor={colors.theme.blue}
              width="8.75rem"
              height="3.25rem"
              iconWidth="100%"
              sizeIcon="2.25em"
              margin="0rem 0rem 0rem 2.563rem"
              icon={fontawesome.icons.faCheck}
              onClick={() => {
                handleClickSave({ subject, content });
                toggleModalSuccess();
              }}
            />
          </div>
          <div
            style={{
              display: 'flex',
              justifyContent: 'center',
              marginTop: '1.563rem',
              marginBottom: '1.563rem',
            }}
          >
            <ButtonCard
              text=""
              backgroundColor={colors.theme.cancel}
              width="19.438rem"
              height="4.563rem"
              iconWidth="100%"
              sizeIcon="2.25em"
              icon={fontawesome.icons.faTrash}
              onClick={toggleModalDelete}
            />
          </div>
        </>
      ) : (
        <div
          style={{
            display: 'flex',
            justifyContent: 'center',
            marginTop: '2.75rem',
          }}
        >
          <ButtonCard
            text=""
            backgroundColor={colors.theme.blue}
            width="8.75rem"
            height="3.25rem"
            iconWidth="100%"
            sizeIcon="2.25em"
            icon={fontawesome.icons.faXmark}
            onClick={() => navigate(-1)}
          />

          <ButtonCard
            text=""
            backgroundColor={colors.theme.blue}
            width="8.75rem"
            height="3.25rem"
            iconWidth="100%"
            sizeIcon="2.25em"
            margin="0rem 0rem 0rem 2.563rem"
            icon={fontawesome.icons.faCheck}
            onClick={() => {
              if (subject.length === 0 || content.length === 0) {
                toggleModalEmpty();
              } else {
                handleClickSave({ subject, content });
                toggleModalSuccess();
              }
            }}
          />
        </div>
      )}
      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Dado cadastrado com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => navigate(-1)}
          />
        </div>
      )}
      {modalDelete && (
        <div style={styles.modal}>
          <Modal
            text="Tem certeza que deseja excluir este dado?"
            closeModal={toggleModalDelete}
            checkButton={() => {
              handleClickDelete();
              navigate(-1);
            }}
            noButton={toggleModalDelete}
          />
        </div>
      )}
      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos necessários."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
      {modalDeleteConfirmed && (
        <div style={styles.modal}>
          <Modal
            text="Dado deletado com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => {
              toggleModalDeleteConfirmed();
              navigate(-1);
            }}
          />
        </div>
      )}
    </div>
  );
}

export default AdicionarDado;
