/* eslint-disable no-return-assign */
import { Category } from '../model/category';
import { User } from '../model/user';
import api from './api';

const serviceName = '/materials';

export interface Material {
  title: string;
  content: string;
  tags: Array<string>;
  author: number;
}

export interface RecvMaterial {
  title: string;
  content: string;
  tags: Array<Category>;
  author: User;
}

export interface CreateMaterialPayload {
  title: string;
  content: string;
  tags: Array<string>;
  author: number;
}

export interface EditMaterialPayload {
  title: string;
  content: string;
  tags: Array<string>;
}

export async function createMaterial(material: Material): Promise<any> {
  let response = null;
  await api
    .post(`${serviceName}`, material)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function deleteMaterial(id: number): Promise<any> {
  let response = null;
  await api
    .delete(`${serviceName}/${id}`)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function editMaterial(
  id: number,
  material: EditMaterialPayload,
): Promise<Material> {
  const response = await api
    .put(`${serviceName}/${id}`, material)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getMaterialById(id: number): Promise<RecvMaterial> {
  const response = await api
    .get(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}
